@@ -9,7 +9,6 @@ import Compiler
 import GetImages
 import MakeChess
 import Join
-import TouchJPEG
 import Control.Monad.State hiding (join)
 import Tools
 import Data.ByteString hiding (take,reverse,dropWhile,takeWhile,drop,map,concat,elem,zip,intercalate)
@@ -28,8 +27,13 @@ import Data.ByteString.UTF8 (toString)
 import Data.List
 import Data.Maybe
 import Data.Char
-deleteImages::ImperativeMonad ()
-deleteImages=return ()
+import MediaWikiParseTree
+import MediaWikiParser
+import SimpleContributors
+import UrlAnalyse
+import Network.URL
+import System.FilePath
+
 
 getExtension:: String->String
 getExtension s = normalizeExtension2 (map toLower (reverse . (takeWhile (/='.')) .reverse $ s))
@@ -111,18 +115,21 @@ runFileMods p filenamebase extension theResolution gals imageNumber pathname =
     imageWidth::Integer
     imageWidth= round ((fromIntegral theResolution) * textWidth / centimetersPerInch)
 
-writeFiles:: FilePath-> String->[Maybe (String,ByteString,[String])]->Integer->[Integer]->IO ()
-writeFiles p pathname theImages theResolution gals = mapM_ go (Prelude.zip ([1..]::[Integer]) theImages)
+writeFiles:: FilePath->FilePath-> String->[Maybe (String,Integer,[String])]->Integer->[Integer]->IO ()
+writeFiles dir p pathname theImages theResolution gals = mapM_ go (Prelude.zip ([1..]::[Integer]) theImages)
   where
-    go (i,Just (n,d,_))= do let filenamebase=(pathname++(show i))
+    go (i,Just (n,ii,_))= 
+                         do let filenamebase=(pathname++(show i))
                             let filename=filenamebase ++"."++(getExtension n)
-                            Data.ByteString.writeFile filename d
+                            file<-Data.ByteString.readFile (dir </> (show ii))
+                            Data.ByteString.writeFile filename file
                             runFileMods p filenamebase (getExtension n) theResolution gals i pathname 
     go _ = return ()
 
 
-makeBabel :: [Char] -> String
-makeBabel x =case Data.Map.lookup xx m of
+makeBabel :: Maybe String->[Char] -> String
+makeBabel b x
+            =case Data.Map.lookup (fromMaybe xx b) m of
                Just v -> decode . unpack $ v
                _ -> case Data.Map.lookup "en" m of
                       Just w -> decode . unpack $  w
@@ -132,10 +139,10 @@ makeBabel x =case Data.Map.lookup xx m of
              (z:_)->z
              _ -> "en"
 
-data LatexConfig = LatexConfig {figures::[Maybe (String,ByteString,[String])],title::String,fullConfig::FullConfig,content::String,hostname::String,theResult::CompileResult, onlyTables::Bool}
+data LatexConfig = LatexConfig {figures::[Maybe (String,Integer,[String])],title::String,fullConfig::FullConfig,content::String,hostname::String,theResult::CompileResult, onlyTables::Bool, lang::Maybe String, theTempDir::String}
 
 runLaTeX::LatexConfig->ImperativeMonad ByteString
-runLaTeX config= liftIO (withSystemTempDirectory "MediaWiki2LaTeX" (runLaTeXCallback config))
+runLaTeX config = liftIO (withSystemTempDirectory "MediaWiki2LaTeX" (runLaTeXCallback config))
 
 runLaTeXCallback:: LatexConfig->FilePath -> IO ByteString
 runLaTeXCallback config pathname = 
@@ -143,9 +150,9 @@ runLaTeXCallback config pathname =
                                        Tools.writeFile (pathname++"/document/main/main.tex") (content config)
                                        Tools.writeFile (pathname++"/document/headers/svg.tex") (if vector (fullConfig config) then "\\newcommand{\\SVGExtension}{pdf}" else "\\newcommand{\\SVGExtension}{png}")
                                        Tools.writeFile (pathname++"/document/headers/title.tex") (All.title config)
-                                       Tools.writeFile (pathname++"/document/headers/babel.tex") (makeBabel (All.hostname config))
+                                       Tools.writeFile (pathname++"/document/headers/babel.tex") (makeBabel (lang config) (All.hostname config))
                                        Tools.writeFile (pathname++"/document/headers/paper.tex") ("\\KOMAoption{paper}{"++(paper (fullConfig config))++"}")
-                                       if (onlyTables config) then return () else All.writeFiles(mainPath (fullConfig config))  (pathname++"/document/images/") (figures config) (resolution (fullConfig config)) (galleryNumbers (theResult config)) 
+                                       if (onlyTables config) then return () else All.writeFiles (theTempDir config) (mainPath (fullConfig config))  (pathname++"/document/images/") (figures config) (resolution (fullConfig config)) (galleryNumbers (theResult config)) 
                                        cwd<-getCurrentDirectory
                                        setCurrentDirectory (pathname++"/document/main")
 
@@ -167,6 +174,14 @@ runLaTeXCallback config pathname =
                                        return result                
  
 
+getLang::URL->IO (Maybe String)
+getLang u = let theUrl = exportURL u in
+              do yy<- geturl theUrl          
+                 case (deepGet2 "html"(parseit minparsers yy)) of 
+                             ((Environment Tag (TagAttr _ m) _):[]) -> return $ Data.Map.lookup "lang" m 
+                             _ -> return $  Nothing
+
+
 catchFun::IOException ->IO String
 catchFun _= return ""
 
@@ -178,14 +193,15 @@ strip l = dropWhileRev isBad . dropWhile isBad
 latexPostamble::String 
 latexPostamble = "\n\\end{longtable}\n\\pagebreak"
 
-imgContrib::Maybe (String, ByteString, [String])->ImperativeMonad (String,Maybe String)
+imgContrib::Maybe (String, Integer, [String])->ImperativeMonad (String,Maybe String)
 imgContrib (Just (_,_,x)) = do img<-getContributors x
                                return (intercalate ", " (keys (fst img)), snd img)
 
 imgContrib _ = return ("",Nothing)
 
-makeImgList :: [Maybe (String, ByteString, [String])]->ImperativeMonad String
-makeImgList imgs = do contrib<-mapM imgContrib imgs 
+makeImgList :: [Maybe (String, Integer, [String])]->ImperativeMonad String
+makeImgList imgs = 
+                   do contrib<-mapM (imgContrib) imgs 
                       let z=concat (map go (zip (zip ([1.. ]::[Integer]) contrib) imgs))
                       return ((toString latexPreamble)++z++(latexPostamble))
   where
@@ -194,29 +210,31 @@ makeImgList imgs = do contrib<-mapM imgContrib imgs
 
 all::FullConfig->ImperativeMonad ()
 all cfg = 
-                                          do st<-get
+                                          do systempdir<-liftIO getTemporaryDirectory
+                                             tempdir<-liftIO $ createTempDirectory systempdir "MediaWiki2LaTeXImages"
+                                             st<-get
                                              templates <- case runMode cfg of
                                                            UserTemplateFile filename -> liftIO (Tools.readFile filename)  
                                                            _ -> return userTemplates
-                                             let url = replace2 (if (take 8 (inputUrl cfg))=="https://"  then "http://"++(drop 8(inputUrl cfg)) else if (take 7 (inputUrl cfg))=="http://"  then (inputUrl cfg) else "http://"++(inputUrl cfg)) "_" " "
-                                             purl<-parseUrl url
+                                             let uurl = replace2 (if (take 8 (inputUrl cfg))=="https://"  then "http://"++(drop 8(inputUrl cfg)) else if (take 7 (inputUrl cfg))=="http://"  then (inputUrl cfg) else "http://"++(inputUrl cfg)) "_" " "
+                                             purl<-parseUrl uurl
+                                             language<-liftIO $ getLang (UrlAnalyse.url purl)
                                              put st{fullUrl= purl}
                                              minInit
                                              text<-load (runMode cfg)
                                              result<-compile (runMode cfg) text templates []
-                                             deleteImages
-                                             theImages<-getImages (images  result) (wikiUrl purl) 
-                                             touchJPEG
-                                             joined<-join (font cfg) (body result) ""
+                                             theImages<-getImages tempdir (images  result) (wikiUrl purl) 
+                                             joined<-join (body result) ""
                                              makeChess
-                                             let theConfig=LatexConfig{content=joined,figures=theImages, All.title=(makeTitle result purl),fullConfig=cfg,All.hostname= (UrlAnalyse.hostname purl),theResult=result,onlyTables=True}
-                                             tabs<-mapM (\x->mapM (\y->runLaTeX theConfig {content=(toString (if (font cfg) then latexUnicodeTableHeader else latexTableHeader))++y++(toString latexTableFooter)}) x) (tablelist result)
+                                             let theConfig=LatexConfig{content=joined,figures=theImages, All.title=(makeTitle result purl),fullConfig=cfg,All.hostname= (UrlAnalyse.hostname purl),theResult=result,onlyTables=True,lang=language,theTempDir=tempdir}
+                                             tabs<-mapM (\x->mapM (\y->runLaTeX theConfig {content=(toString (latexTableHeader))++y++(toString latexTableFooter)}) x) (tablelist result)
                                              newResult<-compile (runMode cfg) text templates tabs
-                                             contrib<-makeContributors
+                                             contrib<-makeContributors (Just (UrlAnalyse.url purl))
                                              pp<-makeImgList theImages
-                                             newContent<-join (font cfg) (body newResult) (contrib++pp)
+                                             newContent<-join (body newResult) (contrib++pp)
                                              pdf<-runLaTeX theConfig {onlyTables=False,theResult=newResult,content=newContent }
                                              liftIO (Data.ByteString.writeFile (outputFilename cfg) pdf)
+                                             liftIO $ removeDirectoryRecursive tempdir
 
 
 
