@@ -9,6 +9,8 @@ import Control.Monad
 import Data.Maybe
 import Control.Monad.State
 import Data.List
+import Tools
+import System.FilePath
 modpath2 :: String -> URL -> URL
 modpath2 s u
   = u{url_path =
@@ -21,7 +23,7 @@ modpath2 s u
 
 
 conv::URL->String->String
-conv u s= if take 5 s == "http:" then s else if take 6 s == "https:" then "http:"++(drop 6 s) else if (take 2 s) =="//" then "http:"++s else exportURL u{url_path=s}
+conv u s= if take 5 s == "http:" then s else if take 6 s == "https:" then "http:"++(drop 6 s) else if (take 2 s) =="//" then "http:"++s else replace2 (exportURL u{url_path= case s of {('/':xs)->xs ; _->s}}) "%25" "%"
 
 
 getImageUrl2:: (String,URL)->Maybe String
@@ -50,34 +52,36 @@ getImageUrl fi u ss =
     q= BStr.unpack (UTF8Str.fromString "\"")
   
 
-getImagePage:: WikiUrl->String-> IO (Maybe ([String],BStr.ByteString))
-getImagePage u ss=do l <- (mapM (geturl . unify . exportURL . modpath2 ss) (parses u)):: IO [String]
+getImagePage:: String->WikiUrl->(Integer,String)-> IO (Maybe ([String],Integer))
+getImagePage dir u (i,ss)=
+                  do l <- (mapM (geturl . unify . exportURL . modpath2 ss) (parses u)):: IO [String]
                      let xx=(map (getImageUrl2) (zip l (parses u)))::[Maybe String]
                      let gg=(zip (parses u) xx)::[(URL,Maybe String)]
                      let yy=(map go gg)::[[(URL,String)]]
                      let zz=(listToMaybe (concat yy))::Maybe (URL,String)
                      case zz of
                       Just (_,x) -> do img <- (geturl2 x)::(IO BStr.ByteString)
-                                       return (Just (map (unify . exportURL . (modpath2 ss)) (parses u),img))
+                                       BStr.writeFile (dir </> (show i)) img
+                                       return (Just (map (unify . exportURL . (modpath2 ss)) (parses u),i))
                       _ -> return Nothing
   where
     go::(URL,Maybe String)->[(URL,String)] 
     go (uu,Just x)= [(uu,x)] 
     go _ = []
 
-doImage:: WikiUrl->String-> IO [Maybe (String,BStr.ByteString,[String])]
-doImage theWikiUrl img = 
-                      do p<-getImagePage theWikiUrl theName
+doImage:: String->WikiUrl->(Integer,String)-> IO [Maybe (String,Integer,[String])]
+doImage dir theWikiUrl img = 
+                      do p<-getImagePage dir theWikiUrl (fst img,theName)
                          case p of
                            Just (u,pp) -> return [Just (theName,pp,u)]
                            _ -> return [Nothing]
   where
-    theName= case dropWhile (/=':') (takeWhile (/= '|') img) of
+    theName= case dropWhile (/=':') (takeWhile (/= '|') (snd img)) of
             (_:xs)->xs
             _-> []
 
             
 
-getImages::[String]->WikiUrl->ImperativeMonad [Maybe (String,BStr.ByteString,[String])]
-getImages images theWikiUrl = do l<-liftIO ((mapM (doImage theWikiUrl) images)) 
-                                 return (concat l)
+getImages::String->[String]->WikiUrl->ImperativeMonad [Maybe (String,Integer,[String])]
+getImages dir images theWikiUrl = do l<-liftIO ((mapM (doImage dir theWikiUrl) (zip [1..] images))) 
+                                     return (concat l)
