@@ -35,10 +35,10 @@ type ImperativeMonad  = ErrorT MyError (StateT ImperativeState IO)
   
 
 data RunMode = HTML| ExpandedTemplates| StandardTemplates | UserTemplateFile String
- deriving Show
+ deriving (Show,Read)
 data SourceMode = Included | Excluded
-  deriving Show
+  deriving (Show,Read)
 
-data FullConfig=FullConfig{resolution::Integer, outputFilename::String, inputUrl::String, runMode::RunMode,paper::String,vector::Bool,copy::Maybe String, font::Bool, mainPath::String}
- deriving Show
+data FullConfig=FullConfig{resolution::Integer, outputFilename::String, inputUrl::String, runMode::RunMode,paper::String,vector::Bool,copy::Maybe String, mainPath::String, server::Maybe Int}
+ deriving (Show,Read)
 
