@@ -4,7 +4,6 @@ import Tools
 import UrlAnalyse
 import Control.Monad.State
 import Control.Monad.Error
-import Network.URL
 import Text.ParserCombinators.Parsec hiding (try)
 import Text.Parsec.Prim
 import Codec.Binary.UTF8.String
@@ -16,54 +15,58 @@ import Data.List hiding (lookup)
 import MagicStrings
 import SimpleContributors
 import WikiHelper
+import MediaWikiParseTree
+import MediaWikiParser
+import Compiler
+import Network.URL
 notendyet :: (String -> ImperativeMonad String)
                    -> ParsecT String () ImperativeMonad String
                    -> ParsecT String () ImperativeMonad String
                    -> String
                    -> ParsecT String () ImperativeMonad String
-notendyet action start end aku = try (do eof
-                                         return aku)
+notendyet action sstart eend aku = try (do eof
+                                           return aku)
                           <|> 
-                          try (do _<-end
-                                  r<-startToEnd action start end
+                          try (do _<-eend
+                                  r<-startToEnd action sstart eend
                                   a<-lift (action aku)
                                   return (a++r) )
                           <|> do a<-anyChar
-                                 notendyet action start end (aku++[a])
+                                 notendyet action sstart eend (aku++[a])
 
 beginning :: (String -> ImperativeMonad String)
                    -> ParsecT String () ImperativeMonad String
                    -> ParsecT String () ImperativeMonad String
                    -> ParsecT String () ImperativeMonad [Char]
-beginning action start end = try (do eof
-                                     return [])
+beginning action sstart eend = try (do eof
+                                       return [])
                       <|>
-                        do _<-start 
-                           ne<-notendyet action start end []
+                        do _<-sstart 
+                           ne<-notendyet action sstart eend []
                            return (ne)   
 startToEnd:: (String-> ImperativeMonad String)->ParsecT String () ImperativeMonad String->ParsecT String () ImperativeMonad String->ParsecT String () ImperativeMonad String 
-startToEnd action start end =try (do eof
-                                     return [])
+startToEnd action sstart eend =try (do eof
+                                       return [])
                       <|>
-                      try (beginning action start end)
+                      try (beginning action sstart eend)
                       <|> do a<-anyChar
-                             s<-startToEnd action start end
+                             s<-startToEnd action sstart eend
                              return (a:s)
 
 zeroAction :: Monad m => t -> t1 -> m [Char]
 zeroAction _ _ = return ""
 
 runAction :: String -> String -> (String -> ImperativeMonad String) -> String -> ImperativeMonad String
-runAction start end action text = do x<-(runParserT (startToEnd action (string start) (string end)) () "" text) 
-                                     case x of 
-                                      Left _  -> return ""
-                                      Right xs  -> return xs
+runAction sstart eend action text = do x<-(runParserT (startToEnd action (string sstart) (string eend)) () "" text) 
+                                       case x of 
+                                         Left _  -> return ""
+                                         Right xs  -> return xs
 
 
 chapterAction :: WikiUrl -> String -> ImperativeMonad String
 chapterAction wurl text= do pp <- liftIO (getpage d (wurl)) 
                             case pp of
-                              Just p -> do _<-addContributors d
+                              Just p -> do _<-addContributors d Nothing
                                            noinclude wurl ("\n\ndhunparserurl " ++ d ++ "\n\n"++p)
                               _ -> return ""
   where
@@ -75,7 +78,7 @@ includeAction=qIncludeAction
 qIncludeAction :: WikiUrl -> String -> ImperativeMonad String
 qIncludeAction wurl text=do pp <- liftIO (getpage d (wurl)) 
                             case pp of
-                              Just p -> do _<-addContributors d
+                              Just p -> do _<-addContributors d Nothing
                                            noinclude wurl ("\n\ndhunparserurl " ++  d ++ "\n\n"++p)
                               _ -> return ""
   where
@@ -90,9 +93,10 @@ langau =fromList [("hi","लेखक"),("ja","著者"),("pl","Autorzy"),("lo","
 
         
 
-makeHeader :: FullWikiUrl -> [Char]
-makeHeader fullurl = "\\chapter{" ++
-                       (case (case splitOn "." (hostname fullurl) of 
+makeHeader :: FullWikiUrl->Maybe String -> [Char]
+makeHeader fullurl m = let mmm = m>>=(\yy->Map.lookup yy langau) in
+                       "\\chapter{" ++
+                       (case mmm `mplus`(case splitOn "." (hostname fullurl) of 
                                 (x:_)-> Map.lookup x langau
                                 _-> Nothing) `mplus` (Map.lookup "en" langau) of
                           Just x -> x
@@ -106,9 +110,15 @@ makeBody m u = concat (map go (sort (toList m)))
     fun xs=xs
     go (_,v)=(show (edits v))++"& \\myhref{"++(concat (map chartransforlink (exportURL (u{ url_path=(fun(href v))}))))++"}{"++ (concat (map chartrans (name v)))++"}\\\\\n"
 
-makeContributors::ImperativeMonad String        
-makeContributors = do st<-get
-                      return ((makeHeader (fullUrl st))++(makeBody (audict st) (url (fullUrl st)))++"\\end{longtable}\n"++"\\pagebreak\n")
+makeContributors:: Maybe URL->ImperativeMonad String        
+makeContributors uu 
+                 = do st<-get
+                      let theUrl = case uu of {Just u->exportURL u;_->makeUrl3 (lemma (fullUrl st)) (hostname (fullUrl st))}
+                      yy<- liftIO $ geturl theUrl          
+                      let lang= case (deepGet2 "html"(parseit minparsers yy)) of 
+                                  ((Environment Tag (TagAttr _ m) _):[]) -> Map.lookup "lang" m 
+                                  _ -> Nothing
+                      return ((makeHeader (fullUrl st) lang )++(makeBody (audict st) (url (fullUrl st)))++"\\end{longtable}\n"++"\\pagebreak\n")
 
 parseUrl::String->ImperativeMonad FullWikiUrl
 parseUrl u = case analyseFull u of 
@@ -117,7 +127,7 @@ parseUrl u = case analyseFull u of
 
 
 getContributors::[String]->ImperativeMonad ((Map String Contributor),Maybe String)
-getContributors u=
+getContributors u =
                  do st<-get
                     put imperativeStateZero                         
                     au<-mapM go u
@@ -128,13 +138,14 @@ getContributors u=
     go uu=do purl<-parseUrl uu
              sst<-get
              put sst{fullUrl= purl}                         
-             addContributors (lemma purl)
+             addContributors (lemma purl) (Just (UrlAnalyse.url purl))
              
 
-addContributors :: [Char] -> ImperativeMonad (Maybe String)
-addContributors theLemma= do sst<-get
+addContributors :: [Char]->Maybe URL-> ImperativeMonad (Maybe String)
+addContributors theLemma uu=
+                          do sst<-get
                              let st= fullUrl sst
-                             au<-liftIO (simpleContributors theLemma (hostname st))
+                             au<-liftIO (simpleContributors theLemma (hostname st) uu)
                              _<-mapM runGo2 au
                              case au of 
                                [(_,__,_,Just lic)]-> return (Just lic)
@@ -185,18 +196,19 @@ replacements :: String -> String
 replacements x = replace2 (replace2 (replace2 (replace2 x "[[Image:Nuvola apps noatun.png|left|20px|Aufgabe]]" "{{Ubung}}") "[[Image:Yes_check.svg|12px]]" "{{TickYes}}") "{{col-break}}" "\n|") "{{Fortran:Vorlage: Table}}" "prettytable"
 
 
-loadPlain :: ImperativeState -> ImperativeMonad [Char]
-loadPlain st= let fu = fullUrl st in
+loadPlain :: ImperativeState ->Maybe URL -> ImperativeMonad [Char]
+loadPlain st uu
+            = let fu = fullUrl st in
                 do pp <- liftIO (getpage (lemma fu) (wikiUrl fu)) 
                    case pp of
-                      Just p -> do _<-addContributors (lemma fu)
+                      Just p -> do _<-addContributors (lemma fu) uu
                                    runActions (wikiUrl fu) p
                                    
                       _ -> throwError (DownloadError (lemma fu) (exportURL (url fu)))
 
 loadHTML ::   ImperativeState -> ImperativeMonad String
 loadHTML st = let fu = fullUrl st in
-              do _<-loadPlain st
+              do _<-loadPlain st (Just (url fu))
                  x<-liftIO (geturl2  (exportURL (url fu)) )
                  return . decode . unpack $ x
 
@@ -205,7 +217,7 @@ loadMediaWiki :: ImperativeState -> ImperativeMonad [Char]
 loadMediaWiki st = let fu = fullUrl st in 
                      do pp<- liftIO (getpage2 (lemma fu) (wikiUrl fu))
                         case pp of 
-                          Just (ss,u)-> do _<-addContributors (lemma fu) 
+                          Just (ss,u)-> do _<-addContributors (lemma fu) Nothing 
                                            s<-liftIO (getExpandedPage (lemma fu) (replace2 (replace2 (replace2 ss "<ref name=" "dhunnamedrefopendhun") "<ref" "dhunrefopendhun") "</ref>" "dhunrefclosedhun") u)
                                            case s of
                                              Just sss -> return (multireplace sss [("&lt;","<"),("&gt;",">"),("&amp;","&"),("dhunrefopendhun","<ref"),("dhunnamedrefopendhun","<ref name="),("dhunrefclosedhun","</ref>")] )          
@@ -223,7 +235,7 @@ load theRunMode=
               do st<-get
                  case theRunMode of 
                    HTML -> loadHTML st
-                   UserTemplateFile _ -> loadPlain st
-                   StandardTemplates -> loadPlain st
+                   UserTemplateFile _ -> loadPlain st Nothing
+                   StandardTemplates -> loadPlain st Nothing 
                    ExpandedTemplates -> loadMediaWiki st
 
