@@ -1,5 +1,4 @@
 module SimpleContributors where
-import Tools
 import Compiler
 import MediaWikiParseTree
 import MediaWikiParser
@@ -17,19 +16,26 @@ import Data.Functor.Identity
 import Text.Parsec.Prim hiding (try,runParser)
 import Control.Monad
 import Licenses
+import Tools
 makeUrl2 :: String -> String -> [Char]
 makeUrl2 theLemma theHost = (unify . exportURL)  (URL {url_path="w/index.php",url_params=[("title",theLemma),("offset",""),("limit","500000"),("action","history")],url_type=Absolute (Host {protocol=HTTP False,host=theHost,port=Nothing})}) 
 
+makeUrl4 :: String -> [Char]
+makeUrl4 uuu = fromMaybe uuu (
+               do uu<-(importURL uuu) 
+                  ti<-Data.List.lookup "title" (url_params uu)
+                  return $ (unify . exportURL)  (URL {url_path=(url_path uu),url_params=[("title",ti),("offset",""),("limit","500000"),("action","history")],url_type=url_type uu})) 
+
 makeUrl3 :: String -> String -> [Char]
 makeUrl3 theLemma theHost = (unify . exportURL)  (URL {url_path="w/index.php",url_params=[("title",theLemma)],url_type=Absolute (Host {protocol=HTTP False,host=theHost,port=Nothing})}) 
 
 deepGet2 ::
         [Char] -> [Anything a] -> [Anything a]
-deepGet2 t ll = concat $ map go ll
+deepGet2 tag ll = concat $ map go ll
   where
-        go (Environment Tag (TagAttr tag m) l)
-          = [Environment Tag (TagAttr tag m) l]++(deepGet2 t l)
-        go (Environment _ _ l) = (deepGet2 t l)
+        go (Environment Tag (TagAttr t m) l) | t==tag
+          = [Environment Tag (TagAttr tag m) l]++(deepGet2 tag l)
+        go (Environment _ _ l) = (deepGet2 tag l)
         go _ = []
 
 getLicense :: [Anything Char] -> Maybe [Char]
@@ -52,13 +58,20 @@ getAuthor x = listToMaybe (concat (map go (deepGet2 "tr" x)))
                              _-> []
    go _ = []
 simpleContributors :: [Char]
-                            -> [Char] -> IO [(String, String, Int,Maybe String)]
+                            -> [Char] -> Maybe URL -> IO [(String, String, Int,Maybe String)]
 
-simpleContributors theLemma theHost =
-      do let theUrl= makeUrl2 theLemma theHost
-         xx<- geturl theUrl
-         let theUrl3 = makeUrl3 theLemma theHost
+simpleContributors theLemma theHost uu =
+      do let theUrl3 = case uu of {Just u->exportURL u;_->makeUrl3 theLemma theHost}
          yy<- geturl theUrl3
+         let gg= (deepGet "li" "id" "ca-history" (parseit minparsers yy)) 
+         let theUrl= makeUrl4 (case gg of
+                 ((Environment Tag (TagAttr _ _) l):[]) -> case deepGet2 "a" l of
+                                                         [Environment Tag (TagAttr _ mm) _]-> case Data.Map.lookup "href" mm of
+                                                                                                  (Just x) -> "http://"++theHost++(replace2 x "&amp;" "&")
+                                                                                                  _ -> []
+                                                         _ -> []
+                 _-> [])
+         xx<- geturl theUrl
          let y= decodeString yy
          let x= decodeString xx
          let dd=(deepGet "a" "class" "mw-userlink" (parseit minparsers x))::[Anything Char]
