@@ -21,8 +21,6 @@ writeFiles pathname filelist= do _<-(mapM (\(name,content) ->Data.ByteString.wri
 latexHeader :: ByteString
 latexHeader = $(embedFile "./latex/my-head.tex")
 
-latexUnicodeHeader :: ByteString
-latexUnicodeHeader = $(embedFile "./latex/my-unihead.tex")
 
 
 latexFooter :: ByteString
@@ -38,8 +36,6 @@ latexTableHeader = $(embedFile "./latex/my-tabhead.tex")
 latexTableFooter :: ByteString
 latexTableFooter = $(embedFile "./latex/my-tabtail.tex")
 
-latexUnicodeTableHeader :: ByteString
-latexUnicodeTableHeader = $(embedFile "./latex/my-unitabhead.tex")
 
 userTemplates :: String
 userTemplates = toString $(embedFile "./latex/templates.user")
