@@ -213,7 +213,7 @@ getLemma s
                let xx = if "index.php" `elem` x 
                           then  
                             case dropWhile (/= "index.php") x of
-                              (y:ys)->ys
+                              (_:ys)->ys
                               _ -> [] 
                           else x
                return $ intercalate "/" xx 
