@@ -7,9 +7,11 @@ import System.Console.GetOpt
 import System.Exit
 import ImperativeState
 import Data.Maybe
+import Hex
+import Server
 import System.FilePath.Posix
 data Flag = Verbose |Vector | Version | Templates String | Resolution String | Paper String
-              |Copy String | Input String | Output String | LibDir String | MediaWiki | HTML | InternalTemplates | MegaFont
+              |Copy String | Input String | Output String | LibDir String | MediaWiki | HTML | InternalTemplates | Hex String | Server String
   deriving (Show,Eq)
 
 versionOption::String
@@ -18,6 +20,8 @@ resolutionOption::String
 resolutionOption="resolution"
 output::String
 output="output"
+hexen::String
+hexen="hex"
 templates::String
 templates="templates"
 url::String
@@ -34,13 +38,15 @@ vectorOption::String
 vectorOption="vector"
 copyOption::String
 copyOption="copy"
-fontOption::String
-fontOption="font"
+serverOption::String
+serverOption="server"
 
 options :: [OptDescr Flag]
 options = [
    Option ['V','?','v'] [versionOption,"help"] (NoArg Version) "show version number"
    , Option ['o']     [output]  (ReqArg Output "FILE")  "output FILE (REQUIRED)"
+   , Option ['x']     [hexen]  (ReqArg Hex "CONFIG")  "hex encoded full configuration for run"
+   , Option ['s']     [serverOption]  (ReqArg Server "PORT")  "run in server mode listen on the given port"
    , Option ['t']     [templates]  (ReqArg Templates "FILE")  "user template map FILE"
    , Option ['r']     [resolutionOption]  (ReqArg Resolution "INTEGER")  "maximum image resolution in dpi INTEGER"
    , Option ['u']     [url]          (ReqArg  Input "URL")  "input URL (REQUIRED)"
@@ -51,7 +57,6 @@ options = [
 
    , Option ['i'] [internal] (NoArg Main.InternalTemplates)  "use internal template definitions"   
    , Option ['c'] [copyOption] (ReqArg Main.Copy "DIRECTORY")  "copy LaTeX tree to DIRECTORY"
-   , Option ['f'] [fontOption] (NoArg MegaFont)  "cover full unicode range using megafont ttf files"   
    ]
     
     
@@ -66,7 +71,7 @@ header = "Usage: mediawiki2latex [OPTION...]"
 
 
 versionHeader :: String
-versionHeader = "mediawiki2latex version 6.9\n"++( usageInfo header options)
+versionHeader = "mediawiki2latex version 7.2\n"++( usageInfo header options)
 
 printVersion:: Eq a => ([Flag], [a]) -> IO ()
 printVersion o = if (Version `elem` (fst o)) || o == ([],[]) then putStrLn versionHeader>>exitSuccess else return ()
@@ -104,6 +109,15 @@ templatesPredicate :: Flag -> Maybe String
 templatesPredicate (Templates x) = Just x
 templatesPredicate _ = Nothing
 
+hexPredicate :: Flag -> Maybe String
+hexPredicate (Hex x) = Just x
+hexPredicate _ = Nothing
+
+serverPredicate :: Flag -> Maybe String
+serverPredicate (Server x) = Just x
+serverPredicate _ = Nothing
+
+
 paperPredicate :: Flag -> Maybe String
 paperPredicate (Paper x) = Just x
 paperPredicate _ = Nothing
@@ -124,7 +138,18 @@ boolToInt _ = 0
 
 checkOpts :: FilePath-> [Flag] -> Either MyError FullConfig
 checkOpts cwd o = 
-           do resolutionOpt <- atMostOne resolutionPredicate resolutionOption o
+ do serverVal <- atMostOne serverPredicate serverOption o
+    case serverVal of
+      Just x-> case reads x of
+                 [(z, _)] -> return FullConfig{resolution=300,outputFilename="",inputUrl="",runMode=ImperativeState.HTML,paper="A4",vector=False,ImperativeState.copy=Nothing,mainPath="",server=Just z}
+                 _->  Left (NotIntegerError serverOption)
+      _ ->
+       do hexVal <- atMostOne hexPredicate hexen o
+          case hexVal of
+           Just x-> return ((read . unhex) x)
+           _->
+            do 
+              resolutionOpt <- atMostOne resolutionPredicate resolutionOption o
               resolutionVal<-case resolutionOpt of 
                            (Just x)-> case reads x of
                                         [(z, _)] -> Right z
@@ -142,7 +167,6 @@ checkOpts cwd o =
               let htmlVal = (Main.HTML `elem` o)
               let temVal = (Main.InternalTemplates `elem` o)
               let vectorVal = (Main.Vector `elem` o)
-              let fontVal = (Main.MegaFont `elem` o)
               let mysum=(boolToInt temVal)+(boolToInt mediaWikiVal)+(boolToInt htmlVal)+(maybeToInt templatesVal)
               if mysum>1 then Left ToManyOptionsError else Right ()
               runModeVal <- if mysum==(1::Integer) 
@@ -152,7 +176,7 @@ checkOpts cwd o =
                                   then Right ExpandedTemplates
                                   else if htmlVal then Right ImperativeState.HTML else Right (StandardTemplates) 
                               else Right ImperativeState.HTML  
-              return FullConfig{resolution=resolutionVal, outputFilename=outputVal,inputUrl=inputVal,runMode=runModeVal,paper=paperVal,vector=vectorVal,copy=copyVal >>=(return.(  cwd </>)),font=fontVal,mainPath=cwd}
+              return (FullConfig{resolution=resolutionVal, outputFilename=outputVal,inputUrl=inputVal,runMode=runModeVal,paper=paperVal,vector=vectorVal,copy=copyVal >>=(return.(  cwd </>)),mainPath=cwd,server=Nothing})
 
 main :: IO ()
 main= do a<-getArgs
@@ -160,10 +184,13 @@ main= do a<-getArgs
          printVersion o
          cwd<-getCurrentDirectory
          case (checkOpts cwd (fst o)) of
-           Right x -> do (xx,_)<-(runStateT (runErrorT (All.all x)) imperativeStateZero)
-                         case xx of 
-                           Left n->print n
-                           _->return ()
+           Right x -> case (server x) of
+                       Just zz-> serve zz
+                       _->
+                        do (xx,_)<-(runStateT (runErrorT (All.all x)) imperativeStateZero)
+                           case xx of 
+                             Left n->print n
+                             _->return ()
            Left y -> print y
          return ()
 
